@@ -1,12 +1,15 @@
+/* -*-mode:c++; c-file-style: "gnu";-*- */
 /*
- *  $Id: FormEntry.cpp,v 1.3 2001/09/02 19:53:17 sbooth Exp $
+ *  $Id: FormEntry.cpp,v 1.13 2007/07/02 18:48:18 sebdiaz Exp $
  *
- *  Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001 Stephen F. Booth
+ *  Copyright (C) 1996 - 2004 Stephen F. Booth <sbooth@gnu.org>
+ *                       2007 Sebastien DIAZ <sebastien.diaz@gmail.com>
+ *  Part of the GNU cgicc library, http://www.gnu.org/software/cgicc
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
  *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) any later version.
+ *  version 3 of the License, or (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,7 +18,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA 
  */
 
 #ifdef __GNUG__
@@ -30,20 +33,55 @@
 // local macro for integer maximum
 #define MAX(a, b) ((a) > (b) ? (a) : (b))
 
-CGICCNS FormEntry& 
-CGICCNS FormEntry::operator= (const FormEntry& entry)
+cgicc::FormEntry& 
+cgicc::FormEntry::operator= (const FormEntry& entry)
 {
-  fName  = entry.getName();
-  fValue = entry.getValue();
+  fName  = entry.fName;
+  fValue = entry.fValue;
 
   return *this;
 }
 
 long
-CGICCNS FormEntry::getIntegerValue(long min, 
-				   long max) 		const
+cgicc::FormEntry::getIntegerValue(long min, 
+				  long max) 		const
 {
-  long value = atol(fValue.c_str());
+  long value = std::atol(fValue.c_str());
+
+  if(value > max)
+    value = max;
+  else if(value < min)
+    value = min;
+  
+  return value;
+}
+
+long
+cgicc::FormEntry::getIntegerValue(long min, 
+				  long max,
+				  bool& bounded) 	const
+{
+  long value = std::atol(fValue.c_str());
+
+  bounded = false;
+
+  if(value > max) {
+    value = max;
+    bounded = true;
+  }
+  else if(value < min) {
+    value = min;
+    bounded = true;
+  }
+  
+  return value;
+}
+
+double
+cgicc::FormEntry::getDoubleValue(double min, 
+				 double max) 		const
+{
+  double value = std::atof(fValue.c_str());
   if(value > max)
     value = max;
   else if(value < min)
@@ -53,41 +91,49 @@ CGICCNS FormEntry::getIntegerValue(long min,
 }
 
 double
-CGICCNS FormEntry::getDoubleValue(double min, 
-				  double max) 		const
+cgicc::FormEntry::getDoubleValue(double min, 
+				 double max,
+				 bool& bounded) 	const
 {
-  double value = atof(fValue.c_str());
-  if(value > max)
+  double value = std::atof(fValue.c_str());
+
+  bounded = false;
+
+  if(value > max) {
     value = max;
-  else if(value < min)
+    bounded = true;
+  }
+  else if(value < min) {
     value = min;
+    bounded = true;
+  }
   
   return value;
 }
 
-STDNS string
-CGICCNS FormEntry::makeString(STDNS string::size_type maxLen, 
-			      bool allowNewlines)	const
+std::string
+cgicc::FormEntry::makeString(std::string::size_type maxLen, 
+			     bool allowNewlines)	const
 {
-  STDNS string::size_type	len 		= 0;
-  STDNS string::size_type	avail 		= maxLen;
-  STDNS string::size_type	crCount 	= 0;
-  STDNS string::size_type	lfCount 	= 0;	
-  STDNS string::const_iterator 	src 		= fValue.begin();
-  STDNS string::const_iterator 	lim 		= fValue.end();
-  STDNS string 			dst;
+  std::string::size_type	len 		= 0;
+  std::string::size_type	avail 		= maxLen;
+  std::string::size_type	crCount 	= 0;
+  std::string::size_type	lfCount 	= 0;	
+  std::string::const_iterator 	src 		= fValue.begin();
+  std::string::const_iterator 	lim 		= fValue.end();
+  std::string 			dst;
 
 
   while(src != lim && len < avail) {
 
     // handle newlines
-    if(*src == '\r' || *src == '\n') {
+    if('\r' == *src || '\n' == *src) {
       crCount = 0;
       lfCount = 0;
       
       // Count the number of each kind of line break ('\r' and '\n')
-      while( (*src == '\r' || *src == '\n') && (src != lim)) {
-	if(*src == '\r') 
+      while( ('\r' == *src || '\n' == *src) && (src != lim)) {
+	if('\r' == *src) 
 	  crCount++;
 	else 
 	  lfCount++;
