@@ -1,12 +1,15 @@
+/* -*-mode:c++; c-file-style: "gnu";-*- */
 /*
- *  $Id: HTMLElement.cpp,v 1.4 2003/07/13 14:20:35 sbooth Exp $
+ *  $Id: HTMLElement.cpp,v 1.8 2007/07/02 18:48:18 sebdiaz Exp $
  *
- *  Copyright (C) 1996 - 2003 Stephen F. Booth
+ *  Copyright (C) 1996 - 2004 Stephen F. Booth <sbooth@gnu.org>
+ *                       2007 Sebastien DIAZ <sebastien.diaz@gmail.com>
+ *  Part of the GNU cgicc library, http://www.gnu.org/software/cgicc
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
  *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) any later version.
+ *  version 3 of the License, or (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,7 +18,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA 
  */
 
 #ifdef __GNUG__
@@ -48,13 +51,13 @@ cgicc::HTMLElement::HTMLElement(const HTMLAttributeList *attributes,
     fType(type),
     fDataSpecified(false)
 {
-  if(attributes != 0)
+  if(0 != attributes)
     fAttributes = new HTMLAttributeList(*attributes);
 
-  if(embedded != 0)
+  if(0 != embedded)
     fEmbedded = new HTMLElementList(*embedded);
 
-  if(data != 0) {
+  if(0 != data) {
     fData = *data;
     fDataSpecified = true;
   }
@@ -88,10 +91,10 @@ cgicc::HTMLElement::operator= (const HTMLElement& element)
   fDataSpecified = element.fDataSpecified;
 
   // perform a deep copy
-  if(fAttributes != 0)
+  if(0 != fAttributes)
     fAttributes = new HTMLAttributeList(*fAttributes);
   
-  if(fEmbedded != 0)
+  if(0 != fEmbedded)
     fEmbedded = new HTMLElementList(*fEmbedded);
   
   return *this;
@@ -114,7 +117,7 @@ cgicc::HTMLElement::setEmbedded(const HTMLElementList& embedded)
 cgicc::HTMLElement&
 cgicc::HTMLElement::add(const HTMLElement& element)
 {
-  if(fEmbedded == 0)
+  if(0 == fEmbedded)
     fEmbedded = new HTMLElementList();
   fEmbedded->add(element);
   return *this;
@@ -123,7 +126,7 @@ cgicc::HTMLElement::add(const HTMLElement& element)
 cgicc::HTMLElement&
 cgicc::HTMLElement::add(HTMLElement *element)
 {
-  if(fEmbedded == 0)
+  if(0 == fEmbedded)
     fEmbedded = new HTMLElementList();
   fEmbedded->add(element);
   return *this;
@@ -132,7 +135,7 @@ cgicc::HTMLElement::add(HTMLElement *element)
 cgicc::HTMLElement&
 cgicc::HTMLElement::set(const std::string& name)
 {
-  if(fAttributes == 0)
+  if(0 == fAttributes)
     fAttributes = new HTMLAttributeList();
   fAttributes->set(name);
   return *this;
@@ -140,9 +143,9 @@ cgicc::HTMLElement::set(const std::string& name)
 
 cgicc:: HTMLElement&
 cgicc::HTMLElement::set(const std::string& name,
-			 const std::string& value)
+			const std::string& value)
 {
-  if(fAttributes == 0)
+  if(0 == fAttributes)
     fAttributes = new HTMLAttributeList();
   fAttributes->set(name, value);
   return *this;
@@ -151,17 +154,17 @@ cgicc::HTMLElement::set(const std::string& name,
 void
 cgicc::HTMLElement::render(std::ostream& out) 	const
 {
-  if(getType() == eBoolean && dataSpecified() == false) {
+  if(eBoolean == getType() && false == dataSpecified()) {
     /* no embedded elements */
-    if(getEmbedded() == 0) {
+    if(0 == fEmbedded) {
       swapState();
       /* getState() == true ===> element is active */
-      if(getState() == true) {
+      if(true == getState()) {
 	out << '<' << getName();
 	/* render attributes, if present */
-	if(getAttributes() != 0) {
+	if(0 != fAttributes) {
 	  out << ' ';
-	  getAttributes()->render(out);
+	  fAttributes->render(out);
 	}
 	out << '>';
       }
@@ -172,35 +175,35 @@ cgicc::HTMLElement::render(std::ostream& out) 	const
     else {
       out << '<' << getName();
       /* render attributes, if present */
-      if(getAttributes() != 0) {
+      if(0 != fAttributes) {
 	out << ' ';
-	getAttributes()->render(out);
+	fAttributes->render(out);
       }
       out << '>';
-      getEmbedded()->render(out);
+      fEmbedded->render(out);
       out << "</" << getName() << '>';
     }
   }
   /* For non-boolean elements */
   else {
-    if(getType() == eAtomic) {
+    if(eAtomic == getType()) {
       out << '<' << getName();
-      if(getAttributes() != 0) {
+      if(0 != fAttributes) {
 	out << ' ';
-	getAttributes()->render(out);
+	fAttributes->render(out);
       }
       out << " />";
     }
     else {
       out << '<' << getName();
-      if(getAttributes() != 0) {
+      if(0 != fAttributes) {
 	out << ' ';
-	getAttributes()->render(out);
+	fAttributes->render(out);
       }
       out << '>';
       
-      if(getEmbedded() != 0)
-	getEmbedded()->render(out);
+      if(0 != fEmbedded)
+	fEmbedded->render(out);
       else
 	out << getData();
       out << "</" << getName() << '>';
