@@ -1,21 +1,24 @@
+/* -*-mode:c++; c-file-style: "gnu";-*- */
 /*
- *  $Id: test.cpp,v 1.16 2001/09/03 16:14:26 sbooth Exp $
+ *  $Id: test.cpp,v 1.27 2007/07/08 20:06:59 sebdiaz Exp $
  *
- *  Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001 Stephen F. Booth
+ *  Copyright (C) 1996 - 2004 Stephen F. Booth <sbooth@gnu.org>
+ *                       2007 Sebastien DIAZ <sebastien.diaz@gmail.com>
+ *  Part of the GNU cgicc library, http://www.gnu.org/software/cgicc
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 3 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA 
  */
 
 /*! \file test.cpp
@@ -33,10 +36,10 @@
 
 #include "cgicc/CgiDefs.h"
 #include "cgicc/Cgicc.h"
-#include "cgicc/HTTPHeaders.h"
+#include "cgicc/HTTPHTMLHeader.h"
 #include "cgicc/HTMLClasses.h"
 
-#if HAVE_UNAME
+#if HAVE_SYS_UTSNAME_H
 #  include <sys/utsname.h>
 #endif
 
@@ -44,26 +47,126 @@
 #  include <sys/time.h>
 #endif
 
-// To use logging, the variable gLogFile MUST be defined, and it _must_
-// be an ofstream
-#if DEBUG
-  STDNS ofstream gLogFile( "/change_this_path/cgicc.log", STDNS ios::app );
-#endif
+#include "styles.h"
 
-#if CGICC_USE_NAMESPACES
-  using namespace std;
-  using namespace cgicc;
-#else
-#  define div div_
-#  define link link_
-#  define select select_
-#endif
+using namespace std;
+using namespace cgicc;
 
 // Function prototypes
 void dumpEnvironment(const CgiEnvironment& env);
 void dumpList(const Cgicc& formData);
 void showForm(const Cgicc& formData);
 
+// Print the form for this CGI
+void
+printForm(const Cgicc& cgi)
+{
+  cout << "<form method=\"post\" action=\"" 
+       << cgi.getEnvironment().getScriptName() << "\">" << endl;
+    
+  cout << "<table>" << endl;
+
+  cout << "<tr><td class=\"title\">Your name</td>"
+       << "<td class=\"form\">"
+       << "<input type=\"text\" name=\"name\" value=\"Uncle Bob\" />"
+       << "</td></tr>" << endl;
+
+  cout << "<tr><td class=\"title\">Your salary in millions<br />(80-120)</td>"
+       << "<td class=\"form\">"
+       << "<input type=\"text\" name=\"bucks\" value=\"93\" />"
+       << "</td></tr>" << endl;
+
+  cout << "<tr><td class=\"title\">Hours you've wasted on the web</td>"
+       << "<td class=\"form\">"
+       << "<input type=\"text\" name=\"time\" value=\"100\" />"
+       << "</td></tr>" << endl;
+
+  cout << "<tr><td class=\"title\">Your thoughts (on anything)</td>"
+       << "<td class=\"form\">"
+       << "<textarea name=\"thoughts\" rows=\"4\" cols=\"40\">"
+       << "I don't have any!</textarea>" << "</td></tr>" << endl;
+
+  cout << "<tr><td class=\"title\">Are you hungry?</td>"
+       << "<td class=\"form\">"
+       << "<input type=\"checkbox\" name=\"hungry\" checked=\"checked\" />"
+       << "Yes</td></tr>" << endl;
+
+  cout << "<tr><td class=\"title\">Your favorite flavors of ice cream</td>"
+       << "<td class=\"form\">"
+       << "<select name=\"flavors\" multiple=\"multiple\">"
+       << "<option value=\"cookie dough\">Cookie Dough</option>"
+       << "<option value=\"rocky road\">Rocky Road</option>"
+       << "<option value=\"chocolate\">Chocolate</option>"
+       << "<option value=\"strawberry\">Strawberry</option>"
+       << "<option value=\"vanilla\">Vanilla</option>"
+       << "</select>" << "</td></tr>" << endl;
+
+  cout << "<tr><td class=\"title\">Your hair color</td>"
+       << "<td class=\"form\">"
+       << "<select name=\"hair\">"
+       << "<option value=\"blond\">Blond</option>"
+       << "<option value=\"brown\">Brown</option>"
+       << "<option value=\"red\">Red</option>"
+       << "<option value=\"black\">Black</option>"
+       << "<option value=\"white\">White</option>"
+       << "<option value=\"green\">Green</option>"
+       << "<option value=\"multicolored\">Multicolored</option>"
+       << "</select>" << "</td></tr>" << endl;
+
+  cout << "<tr><td class=\"title\">Your web browser</td>"
+       << "<td class=\"form\">"
+       << "<input type=\"radio\" name=\"browser\" value=\"Konqueror\""
+       << " checked=\"checked\" />Konqeuror"
+       << "<input type=\"radio\" name=\"browser\" value=\"Lynx\" />Lynx"
+       << "<input type=\"radio\" name=\"browser\" value=\"Mozilla\" />Mozilla"
+       << "<input type=\"radio\" name=\"browser\" value=\"IE\" />IE"
+       << "<input type=\"radio\" name=\"browser\" value=\"Other\" />Other"
+       << "</td></tr>" << endl;
+
+  cout << "<tr><td class=\"title\">Your favorite authors</td>"
+       << "<td class=\"form\">"
+       << "<input type=\"checkbox\" name=\"authors\" value=\"O'Brian\" />"
+       << "O'Brian"
+       << "<input type=\"checkbox\" name=\"authors\" value=\"Feynman\" />" 
+       << "Feynman"
+       << "<input type=\"checkbox\" name=\"authors\" value=\"Camus\" />Camus"
+       << "<input type=\"checkbox\" name=\"authors\" value=\"Conrad\" />Conrad"
+       << "<input type=\"checkbox\" name=\"authors\" value=\"Vergil\" />Vergil"
+       << "<input type=\"checkbox\" name=\"authors\" value=\"Plato\" />Plato"
+       << "</td></tr>" << endl;
+
+  cout << "<tr><td class=\"title\">In the output, show</td>"
+       << "<td class=\"form\">"
+       << "<input type=\"checkbox\" name=\"showEnv\" checked=\"checked\" />"
+       << "Data from CgiEnvironment<br />"
+       << "<input type=\"checkbox\" name=\"showFE\" checked=\"checked\" />"
+       << "All FormEntries<br />"
+       << "<input type=\"checkbox\" name=\"showForm\" checked=\"checked\" />"
+       << "Data from Cgicc"
+       << "</td></tr>" << endl;
+
+  cout << "<tr><td class=\"title\">Exception Handling</td>"
+       << "<td class=\"form\">"
+       << "<input type=\"checkbox\" name=\"throw\" />"
+       << "Throw an exception to test error handling"
+       << "</td></tr>" << endl;
+
+  cout << "<tr><td class=\"title\">Save and Restore</td>"
+       << "<td class=\"form\">"
+       << "<input type=\"checkbox\" name=\"save\" />"
+       <<" Save submission to a file<br />"
+       << "<input type=\"checkbox\" name=\"restore\" />"
+       << "Restore data from the last saved submission"
+       << "</td></tr>" << endl;
+
+  cout << "</table>" << endl;
+
+  cout << "<div class=\"center\"><p>"
+       << "<input type=\"submit\" name=\"submit\"  value=\"Submit\" />"
+       << "<input type=\"reset\" value=\"Nevermind\" />"
+       << "</p></div></form>" << endl;
+}
+
 // Main Street, USA
 int
 main(int /*argc*/, 
@@ -80,7 +183,7 @@ main(int /*argc*/,
     
     // If the user wants to throw an exception, go ahead and do it
     if(cgi.queryCheckbox("throw") && ! cgi.queryCheckbox("restore"))
-      throw STDNS runtime_error("User-requested Exception thrown in main()");
+      throw std::runtime_error("User-requested Exception thrown in main()");
     
     // Output the HTTP headers for an HTML document, and the HTML 4.0 DTD info
     cout << HTTPHTMLHeader() << HTMLDoctype(HTMLDoctype::eStrict) << endl;
@@ -92,36 +195,11 @@ main(int /*argc*/,
 
     // Output the style sheet portion of the header
     cout << style() << comment() << endl;
-    cout << "body { color: black; background-color: white; }" << endl;
-    cout << "hr.half { width: 60%; align: center; }" << endl;
-    cout << "span.red, strong.red { color: red; }" << endl;
-    cout << "div.smaller { font-size: small; }" << endl;
-    cout << "div.notice { border: solid thin; padding: 1em; margin: 1em 0; "
-	 << "background: #ddd; }" << endl;
-    cout << "span.blue { color: blue; }" << endl;
-    cout << "col.title { color: white; background-color: black; ";
-    cout << "font-weight: bold; text-align: center; }" << endl;
-    cout << "col.data { background-color: #DDD; text-align: left; }" << endl;
-    cout << "td.data, tr.data { background-color: #ddd; text-align: left; }"
-	 << endl;
-    cout << "td.grayspecial { background-color: #ddd; text-align: left; }"
-	 << endl;
-    cout << "td.ltgray, tr.ltgray { background-color: #ddd; }" << endl;
-    cout << "td.dkgray, tr.dkgray { background-color: #bbb; }" << endl;
-    cout << "col.black, td.black, td.title, tr.title { color: white; " 
-	 << "background-color: black; font-weight: bold; text-align: center; }"
-	 << endl;
-    cout << "col.gray, td.gray { background-color: #ddd; text-align: center; }"
-	 << endl;
-    cout << "table.cgi { left-margin: auto; right-margin: auto; width: 90%; }"
-	 << endl;
-
+    cout << styles;
     cout << comment() << style() << endl;
 
-    cout << title() << "GNU cgicc v" << cgi.getVersion() << " Test Results" 
+    cout << title() << "GNU cgicc v" << cgi.getVersion() << " Test" 
 	 << title() << endl;
-    cout << meta().set("name", "author").set("content", "Stephen F. Booth") 
-	 << endl;
 
     cout << head() << endl;
     
@@ -129,7 +207,7 @@ main(int /*argc*/,
     cout << body() << endl;
 
     cout << h1() << "GNU cgi" << span("cc").set("class","red")
-	 << " v"<< cgi.getVersion() << " Test Results" << h1() << endl;
+	 << " v"<< cgi.getVersion() << " Test" << h1() << endl;
     
     // Get a pointer to the environment
     const CgiEnvironment& env = cgi.getEnvironment();
@@ -143,12 +221,13 @@ main(int /*argc*/,
     
     // If the user wants to save the submission, do it
     if(cgi.queryCheckbox("save")) {
+      // Make sure the save file is readable and writable by the CGI process
       cgi.save("save");
       cout << p(h2("Data Saved")) << endl;
       
-      cout << CGICCNS div().set("class", "notice") << endl;
+      cout << cgicc::div().set("class", "notice") << endl;
       cout << "Your data has been saved, and may be restored (by anyone) "
-	   << "via the same form." << endl << CGICCNS div() << p() << endl;
+	   << "via the same form." << endl << cgicc::div() << p() << endl;
     }
 
     // If the user wants to restore from the last submission, do it
@@ -156,9 +235,9 @@ main(int /*argc*/,
       cgi.restore("save");
       cout << p(h2("Data Restored")) << endl;
       
-      cout << CGICCNS div().set("class", "notice") << endl;
+      cout << cgicc::div().set("class", "notice") << endl;
       cout << "The data displayed has been restored from a file on disk."
-	   << endl << CGICCNS div() << p() << endl;
+	   << endl << cgicc::div() << p() << endl;
     }
     
     // If the user requested a dump of the environment,
@@ -182,18 +261,15 @@ main(int /*argc*/,
     if(cgi.queryCheckbox("showForm"))
       showForm(cgi);
 
-    // Now print out a footer with some fun info
-    cout << p() << CGICCNS div().set("align","center");
-    cout << a("Back to form").set("href", cgi.getEnvironment().getReferrer()) 
-	 << endl;
-    cout << CGICCNS div() << br() << hr(set("class","half")) << endl;
+    // Print out the form to do it again
+    cout << br() << endl;
+    printForm(cgi);
+    cout << hr().set("class", "half") << endl;
     
     // Information on cgicc
-    cout << CGICCNS div().set("align","center").set("class","smaller") << endl;
+    cout << cgicc::div().set("align","center").set("class","smaller") << endl;
     cout << "GNU cgi" << span("cc").set("class","red") << " v";
-    cout << cgi.getVersion();
-    cout << " by " << a("Stephen F. Booth")
-      .set("href", "mailto:sbooth@gnu.org") << br() << endl;
+    cout << cgi.getVersion() << br() << endl;
     cout << "Compiled at " << cgi.getCompileTime();
     cout << " on " << cgi.getCompileDate() << br() << endl;
 
@@ -217,11 +293,11 @@ main(int /*argc*/,
       + (end.tv_usec - start.tv_usec);
 
     cout << br() << "Total time for request = " << us << " us";
-    cout << " (" << (double) (us/1000000.0) << " s)";
+    cout << " (" << static_cast<double>(us/1000000.0) << " s)";
 #endif
 
     // End of document
-    cout << CGICCNS div() << endl;
+    cout << cgicc::div() << endl;
     cout << body() << html() << endl;
 
     // No chance for failure in this example
@@ -229,7 +305,7 @@ main(int /*argc*/,
   }
 
   // Did any errors occur?
-  catch(const STDNS exception& e) {
+  catch(const std::exception& e) {
 
     // This is a dummy exception handler, as it doesn't really do
     // anything except print out information.
@@ -239,7 +315,7 @@ main(int /*argc*/,
     html::reset(); 	head::reset(); 		body::reset();
     title::reset(); 	h1::reset(); 		h4::reset();
     comment::reset(); 	td::reset(); 		tr::reset(); 
-    table::reset();	CGICCNS div::reset(); 	p::reset(); 
+    table::reset();	cgicc::div::reset(); 	p::reset(); 
     a::reset();		h2::reset(); 		colgroup::reset();
 
     // Output the HTTP headers for an HTML document, and the HTML 4.0 DTD info
@@ -261,8 +337,6 @@ main(int /*argc*/,
     cout << comment() << style() << endl;
 
     cout << title("GNU cgicc exception") << endl;
-    cout << meta().set("name", "author")
-		  .set("content", "Stephen F. Booth") << endl;
     cout << head() << endl;
     
     cout << body() << endl;
@@ -270,12 +344,12 @@ main(int /*argc*/,
     cout << h1() << "GNU cgi" << span("cc", set("class","red"))
 	 << " caught an exception" << h1() << endl; 
   
-    cout << CGICCNS div().set("align","center").set("class","notice") << endl;
+    cout << cgicc::div().set("align","center").set("class","notice") << endl;
 
     cout << h2(e.what()) << endl;
 
     // End of document
-    cout << CGICCNS div() << endl;
+    cout << cgicc::div() << endl;
     cout << hr().set("class","half") << endl;
     cout << body() << html() << endl;
     
@@ -291,17 +365,9 @@ dumpEnvironment(const CgiEnvironment& env)
   // Almost all of this code is for HTML formatting
   cout << h2("Environment information from CgiEnvironment") << endl;
   
-  cout << CGICCNS div().set("align","center") << endl;
+  cout << cgicc::div().set("align","center") << endl;
   
-  cout << table().set("border","0").set("rules","none").set("frame","void")
-		 .set("cellspacing","2").set("cellpadding","2")
-		 .set("class","cgi") << endl;
-  cout << colgroup().set("span","2") << endl;
-  cout << col().set("align","center").set("class","title").set("span","1") 
-       << endl;
-  cout << col().set("align","left").set("class","data").set("span","1") 
-       << endl;
-  cout << colgroup() << endl;
+  cout << table() << endl;
   
   cout << tr() << td("Request Method").set("class","title") 
        << td(env.getRequestMethod()).set("class","data") << tr() << endl;
@@ -361,7 +427,7 @@ dumpEnvironment(const CgiEnvironment& env)
   cout << tr() << td("Redirect Status").set("class","title") 
        << td(env.getRedirectStatus()).set("class","data") << tr() << endl;
   
-  cout << table() << CGICCNS div() << endl;
+  cout << table() << cgicc::div() << endl;
 }
 
 // Print out the value of every form element
@@ -370,14 +436,9 @@ dumpList(const Cgicc& formData)
 {
   cout << h2("Form Data via vector") << endl;
   
-  cout << CGICCNS div().set("align","center") << endl;
+  cout << cgicc::div().set("align","center") << endl;
   
-  cout << table().set("border","0").set("rules","none").set("frame","void")
-		 .set("cellspacing","2").set("cellpadding","2")
-		 .set("class","cgi") << endl;
-  cout << colgroup().set("span","2") << endl;
-  cout << col().set("align","center").set("span","2") << endl;
-  cout << colgroup() << endl;
+  cout << table()<< endl;
   
   cout << tr().set("class","title") << td("Element Name") 
        << td("Element Value") << tr() << endl;
@@ -390,7 +451,7 @@ dumpList(const Cgicc& formData)
     cout << tr().set("class","data") << td(iter->getName()) 
 	 << td(iter->getValue()) << tr() << endl;
   }
-  cout << table() << CGICCNS div() << endl;
+  cout << table() << cgicc::div() << endl;
 }
 
 // Print out information customized for each element
@@ -401,7 +462,7 @@ showForm(const Cgicc& formData)
   // I am using an if statement to check if each element is found
   cout << h2("Form Data via Cgicc") << endl;
   
-  cout << CGICCNS div().set("class","notice") << endl;
+  cout << cgicc::div().set("class","notice") << endl;
 
   //getElement
   const_form_iterator name = formData.getElement("name");
@@ -429,8 +490,8 @@ showForm(const Cgicc& formData)
   // getElement and getStrippedValue
   const_form_iterator thoughts = formData.getElement("thoughts");
   if(thoughts != (*formData).end() && ! (*thoughts).isEmpty()) {
-    STDNS string temp = (*thoughts).getStrippedValue();
-    cout << "Your thoughts : " << temp << br() << endl;
+    std::string temp = (*thoughts).getStrippedValue();
+    cout << "Your thoughts: " << temp << br() << endl;
   }
   else
     cout << "You don't have any thoughts!?" << br() << endl;
@@ -442,11 +503,11 @@ showForm(const Cgicc& formData)
     cout << "You are not hungry." << br() << endl;
 
   // getElement
-  STDNS vector<FormEntry> flavors;
+  std::vector<FormEntry> flavors;
   formData.getElement("flavors", flavors);
   if(! flavors.empty()) {
     cout << "You like ";
-    for(STDNS string::size_type i = 0; i < flavors.size(); i++) {
+    for(std::string::size_type i = 0; i < flavors.size(); i++) {
       cout << flavors[i].getValue();
       if(i < flavors.size() - 2)
 	cout << ", ";
@@ -465,28 +526,25 @@ showForm(const Cgicc& formData)
   else
     cout << "You don't have any hair." << br() << endl;
   
-  const_form_iterator vote = formData.getElement("vote");
-  if(vote != (*formData).end())
-    cout << "You voted for " << **vote << '.' << br() << endl;
-  else
-    cout << "This should never happen. ERROR!" << br() << endl;
+  cout << "You surf the web with " << formData("browser") << '.' 
+       << br() << endl;
   
   // getElement
-  STDNS vector<FormEntry> friends;
-  formData.getElement("friends", friends);
-  if(! friends.empty()) {
-    cout << "You like ";
-    for(STDNS string::size_type i = 0; i < friends.size(); i++) {
-      cout << friends[i].getValue();
-      if(i < friends.size() - 2)
+  std::vector<FormEntry> authors;
+  formData.getElement("authors", authors);
+  if(! authors.empty()) {
+    cout << "You like to read books by ";
+    for(std::string::size_type i = 0; i < authors.size(); ++i) {
+      cout << authors[i].getValue();
+      if(i < authors.size() - 2)
 	cout << ", ";
-      else if(i == friends.size() - 2)
+      else if(i == authors.size() - 2)
 	cout << " and ";
     }
-    cout << " on Friends." << br() << endl;
+    cout << "." << br() << endl;
   }
   else
-    cout << "You don't watch Friends!?" << br() << endl;
+    cout << "You don't like to read!?" << br() << endl;
   
-  cout << CGICCNS div() << endl;
+  cout << cgicc::div() << endl;
 }
